==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/externalscript/kdevexternalscript.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=system-run
Exec=
Comment=Run external scripts or applications to manipulate the editor contents or do other arbitrary actions.
Comment[bs]=Pokreni spoljne skripte ili aplikacija za manipulaciju sadržaja uređivača ili  druge proizvoljne radnje.
Comment[ca]=Executa scripts externs o aplicacions per a manipular el contingut de l'editor o altres accions arbitràries.
Comment[ca@valencia]=Executa scripts externs o aplicacions per a manipular el contingut de l'editor o altres accions arbitràries.
Comment[da]=Kør eksterne scripts eller programmer til manipulering af editor-indholdet eller foretag andre handlinger.
Comment[de]=Führen Sie externe Skripte oder Programme zum Verändern des Editorinhalts oder für beliebige andere Aktionen aus.
Comment[el]=Εκτέλεση εξωτερικών σεναρίων ή εφαρμογών για χειρισμό του περιεχομένου ""του κειμενογράφου ή για οποιεσδήποτε άλλες ενέργειες.
Comment[en_GB]=Run external scripts or applications to manipulate the editor contents or do other arbitrary actions.
Comment[es]=Ejecutar aplicaciones o scripts externos para manipular el contenido del editor o realizar otras acciones.
Comment[et]=Välised skriptid või rakendused, mis võimaldavad muuta redaktori sisu või ette võtta mingeid muid toiminguid.
Comment[fi]=Suorittaa ulkoisia skriptejä tai sovelluksia editorisisällön manipuloimiseksi tai muiden satunnaisten tehtävien tekemiseksi.
Comment[fr]=Lancer des scripts ou des applications externes pour manipuler le contenu de l'éditeur ou effectuer d'autres actions arbitraires.
Comment[gl]=Executa scripts externos ou programas para manipular os contidos do editor ou levar a cabo outras accións.
Comment[it]=Eseguire script o applicazioni esterne per manipolare il contenuto dell'editor o per fare altre azioni.
Comment[kk]=Редактор мазмұнын өңдеу не басқа да істерге арналған сыртқы скрипт не бағдарламаны орындау.
Comment[nb]=Kjør eksterne skripter eller programmer for å behandle redigeringsinnholdet eller utføre andre vilkårlige handlinger.
Comment[nds]=Utföhren vun extern Skripten oder Programmen för't Ännern vun den Editor-Inholt oder anner Akschonen.
Comment[nl]=Externe scripts of programma's uitvoeren om de inhoud van de bewerker te manipuleren of andere acties uit te voeren.
Comment[pl]=Uruchamiaj zewnętrzne skrypty lub programy, aby manipulować zawartością edytora lub innymi dowolnymi działaniami.
Comment[pt]=Executa programas ou aplicações externa para manipular o conteúdo do editor ou efectua outras acções arbitrárias.
Comment[pt_BR]=Execute scripts externos ou aplicativos para manipular os conteúdos do editor ou para fazer outras ações ordinárias.
Comment[ru]=Запускает внешние сценарии или приложения, взаимодействующие с редактором кода и выполняющие другие действия.
Comment[sk]=Spustí externé skripty alebo aplikácie na manipuláciu s obsahom editora alebo robí iné ľubovoľné akcie.
Comment[sl]=Zaganjajte zunanje skripte ali programe, ki upravljajo z vsebino urejevalnika ali pa opravljajo druga poljubna dejanja.
Comment[sv]=Kör externa skript eller program för att behandla editorns innehåll eller utför andra godtyckliga åtgärder.
Comment[tr]=Düzenleyici içeriğini değiştirmek ve diğer istenilen eylemler için dış betikleri veya uygulamaları çalıştır.
Comment[uk]=Запускає зовнішні скрипти або програми для обробки текстових даних редактора або виконання інших потрібних дій.
Comment[x-test]=xxRun external scripts or applications to manipulate the editor contents or do other arbitrary actions.xx
Comment[zh_CN]=运行外部脚本或应用程序来处理编辑器内容或者执行其它任意动作。
Comment[zh_TW]=執行外部文稿或應用程式來運用編輯器內的內容，或是做各種動作。
Name=External Scripts
Name[bg]=Външни скриптове
Name[bs]=Spoljnje skripte
Name[ca]=Scripts externs
Name[ca@valencia]=Scripts externs
Name[da]=Eksterne scripts
Name[de]=Externe Skripte
Name[el]=Εξωτερικά σενάρια
Name[en_GB]=External Scripts
Name[es]=Scripts externos
Name[et]=Välised skriptid
Name[fi]=Ulkoiset skriptit
Name[fr]=Scripts externes
Name[gl]=Scripts externos
Name[hu]=Külső parancsfájlok
Name[it]=Script esterni
Name[ja]=外部スクリプト
Name[kk]=Сыртқы скрипттер
Name[nb]=Eksterne skripter
Name[nds]=Extern Skripten
Name[nl]=Externe scripts
Name[pl]=Zewnętrzne skrypty
Name[pt]=Programas Externos
Name[pt_BR]=Scripts externos
Name[ru]=Внешние сценарии
Name[sk]=Externé skripty
Name[sl]=Zunanji skripti
Name[sv]=Externa skript
Name[tr]=Dış Betikler
Name[ug]=سىرتقى قوليازما پروگرامما
Name[uk]=Зовнішні скрипти
Name[x-test]=xxExternal Scriptsxx
Name[zh_CN]=外部脚本
Name[zh_TW]=外部文稿
GenericName=External Scripts
GenericName[bg]=Външни скриптове
GenericName[bs]=Spoljnje skripte
GenericName[ca]=Scripts externs
GenericName[ca@valencia]=Scripts externs
GenericName[da]=Eksterne scripts
GenericName[de]=Externe Skripte
GenericName[el]=Εξωτερικά σενάρια
GenericName[en_GB]=External Scripts
GenericName[es]=Scripts externos
GenericName[et]=Välised skriptid
GenericName[fi]=Ulkoiset skriptit
GenericName[fr]=Scripts externes
GenericName[gl]=Scripts externos
GenericName[hu]=Külső parancsfájlok
GenericName[it]=Script esterni
GenericName[ja]=外部スクリプト
GenericName[kk]=Сыртқы скрипттер
GenericName[nb]=Eksterne skripter
GenericName[nds]=Extern Skripten
GenericName[nl]=Externe scripts
GenericName[pl]=Zewnętrzne skrypty
GenericName[pt]=Programas Externos
GenericName[pt_BR]=Scripts externos
GenericName[ru]=Внешние сценарии
GenericName[sk]=Externé skripty
GenericName[sl]=Zunanji skripti
GenericName[sv]=Externa skript
GenericName[tr]=Dış Betikler
GenericName[ug]=سىرتقى قوليازما پروگرامما
GenericName[uk]=Зовнішні скрипти
GenericName[x-test]=xxExternal Scriptsxx
GenericName[zh_CN]=外部脚本
GenericName[zh_TW]=外部文稿
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevexternalscript
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevexternalscript
X-KDE-PluginInfo-Author=Milian Wolff
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Interfaces=org.kdevelop.IPlugin
X-KDevelop-Mode=GUI
X-KDevelop-IRequired=org.kdevelop.IOutputView

==> kdevplatform-1.7.1.tar.xz: kdevplatform-1.7.1/plugins/externalscript/kdevexternalscript.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=system-run
Exec=
Comment=Run external scripts or applications to manipulate the editor contents or do other arbitrary actions.
Comment[bs]=Pokreni spoljne skripte ili aplikacija za manipulaciju sadržaja uređivačak ili  druge proizvoljne radnje.
Comment[ca]=Executa scripts externs o aplicacions per a manipular el contingut de l'editor o altres accions arbitràries.
Comment[ca@valencia]=Executa scripts externs o aplicacions per a manipular el contingut de l'editor o altres accions arbitràries.
Comment[da]=Kør eksterne scripts eller programmer til manipulering af editor-indholdet eller foretag andre handlinger.
Comment[de]=Führen Sie externe Skripte oder Programme zum Verändern des Editorinhalts oder für beliebige andere Aktionen aus.
Comment[el]=Εκτέλεση εξωτερικών σεναρίων ή εφαρμογών για χειρισμό του περιεχομένου ""του κειμενογράφου ή για οποιεσδήποτε άλλες ενέργειες.
Comment[en_GB]=Run external scripts or applications to manipulate the editor contents or do other arbitrary actions.
Comment[es]=Ejecutar aplicaciones o scripts externos para manipular el contenido del editor o realizar otras acciones.
Comment[et]=Välised skriptid või rakendused, mis võimaldavad muuta redaktori sisu või ette võtta mingeid muid toiminguid.
Comment[fi]=Suorittaa ulkoisia skriptejä tai sovelluksia editorisisällön manipuloimiseksi tai muiden satunnaisten tehtävien tekemiseksi.
Comment[fr]=Lancer des scripts ou des applications externes pour manipuler le contenu de l'éditeur ou effectuer d'autres actions arbitraires.
Comment[gl]=Executa scripts externos ou programas para manipular os contidos do editor ou levar a cabo outras accións.
Comment[it]=Eseguire script o applicazioni esterne per manipolare il contenuto dell'editor o per fare altre azioni.
Comment[kk]=Редактор мазмұнын өңдеу не басқа да істерге арналған сыртқы скрипт не бағдарламаны орындау.
Comment[nb]=Kjør eksterne skripter eller programmer for å behandle redigeringsinnholdet eller utføre andre vilkårlige handlinger.
Comment[nds]=Utföhren vun extern Skripten oder Programmen för't Ännern vun den Editor-Inholt oder anner Akschonen.
Comment[nl]=Externe scripts of programma's uitvoeren om de inhoud van de bewerker te manipuleren of andere acties uit te voeren.
Comment[pl]=Uruchamiaj zewnętrzne skrypty lub programy, aby manipulować zawartością edytora lub innymi dowolnymi działaniami.
Comment[pt]=Executa programas ou aplicações externa para manipular o conteúdo do editor ou efectua outras acções arbitrárias.
Comment[pt_BR]=Execute scripts externos ou aplicativos para manipular os conteúdos do editor ou para fazer outras ações ordinárias.
Comment[ru]=Запускает внешние сценарии или приложения, взаимодействующие с редактором кода и выполняющие другие действия.
Comment[sk]=Spustí externé skripty alebo aplikácie na manipuláciu s obsahom editora alebo robí iné ľubovoľné akcie.
Comment[sl]=Zaganjajte zunanje skripte ali programe, ki upravljajo z vsebino urejevalnika ali pa opravljajo druga poljubna dejanja.
Comment[sv]=Kör externa skript eller program för att behandla editorns innehåll eller utför andra godtyckliga åtgärder.
Comment[tr]=Düzenleyici içeriğini değiştirmek ve diğer istenilen eylemler için dış betikleri veya uygulamaları çalıştır.
Comment[uk]=Запускає зовнішні скрипти або програми для обробки текстових даних редактора або виконання інших потрібних дій.
Comment[x-test]=xxRun external scripts or applications to manipulate the editor contents or do other arbitrary actions.xx
Comment[zh_CN]=运行外部脚本或应用程序来处理编辑器内容或者执行其它任意动作。
Comment[zh_TW]=執行外部文稿或應用程式來運用編輯器內的內容，或是做各種動作。
Name=External Scripts
Name[bg]=Външни скриптове
Name[bs]=Spoljnje skripte
Name[ca]=Scripts externs
Name[ca@valencia]=Scripts externs
Name[da]=Eksterne scripts
Name[de]=Externe Skripte
Name[el]=Εξωτερικά σενάρια
Name[en_GB]=External Scripts
Name[es]=Scripts externos
Name[et]=Välised skriptid
Name[fi]=Ulkoiset skriptit
Name[fr]=Scripts externes
Name[gl]=Scripts externos
Name[hu]=Külső parancsfájlok
Name[it]=Script esterni
Name[ja]=外部スクリプト
Name[kk]=Сыртқы скрипттер
Name[nb]=Eksterne skripter
Name[nds]=Extern Skripten
Name[nl]=Externe scripts
Name[pl]=Zewnętrzne skrypty
Name[pt]=Programas Externos
Name[pt_BR]=Scripts externos
Name[ru]=Внешние сценарии
Name[sk]=Externé skripty
Name[sl]=Zunanji skripti
Name[sv]=Externa skript
Name[tr]=Dış Betikler
Name[ug]=سىرتقى قوليازما پروگرامما
Name[uk]=Зовнішні скрипти
Name[x-test]=xxExternal Scriptsxx
Name[zh_CN]=外部脚本
Name[zh_TW]=外部文稿
GenericName=External Scripts
GenericName[bg]=Външни скриптове
GenericName[bs]=Spoljnje skripte
GenericName[ca]=Scripts externs
GenericName[ca@valencia]=Scripts externs
GenericName[da]=Eksterne scripts
GenericName[de]=Externe Skripte
GenericName[el]=Εξωτερικά σενάρια
GenericName[en_GB]=External Scripts
GenericName[es]=Scripts externos
GenericName[et]=Välised skriptid
GenericName[fi]=Ulkoiset skriptit
GenericName[fr]=Scripts externes
GenericName[gl]=Scripts externos
GenericName[hu]=Külső parancsfájlok
GenericName[it]=Script esterni
GenericName[ja]=外部スクリプト
GenericName[kk]=Сыртқы скрипттер
GenericName[nb]=Eksterne skripter
GenericName[nds]=Extern Skripten
GenericName[nl]=Externe scripts
GenericName[pl]=Zewnętrzne skrypty
GenericName[pt]=Programas Externos
GenericName[pt_BR]=Scripts externos
GenericName[ru]=Внешние сценарии
GenericName[sk]=Externé skripty
GenericName[sl]=Zunanji skripti
GenericName[sv]=Externa skript
GenericName[tr]=Dış Betikler
GenericName[ug]=سىرتقى قوليازما پروگرامما
GenericName[uk]=Зовнішні скрипти
GenericName[x-test]=xxExternal Scriptsxx
GenericName[zh_CN]=外部脚本
GenericName[zh_TW]=外部文稿
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevexternalscript
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevexternalscript
X-KDE-PluginInfo-Author=Milian Wolff
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Interfaces=org.kdevelop.IPlugin
X-KDevelop-Mode=GUI
X-KDevelop-IRequired=org.kdevelop.IOutputView
